==> image-saas-service-0.0.904-sources.jar: com/xforceplus/imagesaas/controller/CompareTicketCustomsDeclarationController.java <==
package com.xforceplus.imagesaas.controller;


import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.xforceplus.ultraman.bocp.gen.plugins.XfPage;
import org.springframework.web.bind.annotation.*;
import org.springframework.beans.factory.annotation.Autowired;
import com.xforceplus.ultraman.bocp.gen.api.XfR;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.imagesaas.entity.CompareTicketCustomsDeclaration;
import com.xforceplus.imagesaas.service.ICompareTicketCustomsDeclarationService;
import lombok.AllArgsConstructor;
import com.xforceplus.ultraman.bocp.gen.util.ObjectCopyUtils;
import com.xforceplus.ultraman.bocp.gen.sql.pojo.ConditionQueryRequest;
import java.util.HashMap;
import java.util.Map;
import org.springframework.stereotype.Controller;
/**
 * 比对报关单前端控制器
 *
 * @author ultraman
 * @date 2022-06-30
 */
@RestController
public class CompareTicketCustomsDeclarationController {

  @Autowired
  private ICompareTicketCustomsDeclarationService compareTicketCustomsDeclarationServiceImpl;


  /**
   * 查询所有-分页模式
   * @param page 分页对象
   * @param compareTicketCustomsDeclaration 比对报关单
   * @return
   */
  @GetMapping("/compareticketcustomsdeclarations" )
  public XfR getCompareTicketCustomsDeclarations(XfPage page, CompareTicketCustomsDeclaration compareTicketCustomsDeclaration) {
    return XfR.ok(compareTicketCustomsDeclarationServiceImpl.page(page, Wrappers.query(compareTicketCustomsDeclaration)));
  }

  /**
   * 通过id查询比对报关单
   * @param  id
   * @return XfR
   */
  @GetMapping("/compareticketcustomsdeclarations/{id}")
  public XfR getById(@PathVariable Long id) {
     return XfR.ok(compareTicketCustomsDeclarationServiceImpl.getById(id));
  }

  /**
   * 新增比对报关单
   * @param compareTicketCustomsDeclaration 比对报关单
   * @return XfR
   */
  @PostMapping("/compareticketcustomsdeclarations")
  public XfR save(@RequestBody CompareTicketCustomsDeclaration compareTicketCustomsDeclaration) {
     return XfR.ok(compareTicketCustomsDeclarationServiceImpl.save(compareTicketCustomsDeclaration));
  }

  /**
   * 修改-传入修改后的全部数据比对报关单
   * @param compareTicketCustomsDeclaration 比对报关单
   * @return XfR
   */
  @PutMapping("/compareticketcustomsdeclarations/{id}")
  public XfR putUpdate(@RequestBody CompareTicketCustomsDeclaration compareTicketCustomsDeclaration,@PathVariable Long id) {
      compareTicketCustomsDeclaration.setId(id);
      return XfR.ok(compareTicketCustomsDeclarationServiceImpl.updateById(compareTicketCustomsDeclaration));
  }

  /**
   * 修改-传入修改的数据比对报关单
   * @param compareTicketCustomsDeclaration 比对报关单
   * @return XfR
   */
  @PatchMapping("/compareticketcustomsdeclarations/{id}")
  public XfR patchUpdate(@RequestBody CompareTicketCustomsDeclaration compareTicketCustomsDeclaration,@PathVariable Long id) {
      CompareTicketCustomsDeclaration upcompareTicketCustomsDeclaration = compareTicketCustomsDeclarationServiceImpl.getById(id);
      if(upcompareTicketCustomsDeclaration != null){
        upcompareTicketCustomsDeclaration = ObjectCopyUtils.copyProperties(compareTicketCustomsDeclaration,upcompareTicketCustomsDeclaration,true);
      }
      return XfR.ok(compareTicketCustomsDeclarationServiceImpl.updateById(upcompareTicketCustomsDeclaration));
  }

  /**
   * 通过id删除比对报关单
   * @param  id
   * @return XfR
   */
  @DeleteMapping("/compareticketcustomsdeclarations/{id}")
  public XfR removeById(@PathVariable Long id) {
     return XfR.ok(compareTicketCustomsDeclarationServiceImpl.removeById(id));
  }

  @PostMapping("/compareticketcustomsdeclarations/query")
  public XfR querys(@RequestBody ConditionQueryRequest condition) {
     Map<String, Object> params = new HashMap();
     params.put("tableName", "compare_ticket_customs_declaration");
     params.put("request", condition);

     return XfR.ok(compareTicketCustomsDeclarationServiceImpl.querys(params));
  }

}

==> image-saas-service-0.1.77-sources.jar: com/xforceplus/imagesaas/controller/CompareTicketCustomsDeclarationController.java <==
package com.xforceplus.imagesaas.controller;


import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.xforceplus.ultraman.bocp.gen.plugins.XfPage;
import org.springframework.web.bind.annotation.*;
import org.springframework.beans.factory.annotation.Autowired;
import com.xforceplus.ultraman.bocp.gen.api.XfR;
import org.apache.commons.lang3.StringUtils;
import com.xforceplus.imagesaas.entity.CompareTicketCustomsDeclaration;
import com.xforceplus.imagesaas.service.ICompareTicketCustomsDeclarationService;
import lombok.AllArgsConstructor;
import com.xforceplus.ultraman.bocp.gen.util.ObjectCopyUtils;
import com.xforceplus.ultraman.bocp.gen.sql.pojo.ConditionQueryRequest;
import java.util.HashMap;
import java.util.Map;
import org.springframework.stereotype.Controller;
/**
 * 比对报关单前端控制器
 *
 * @author ultraman
 * @date 2023-03-06
 */
@RestController
public class CompareTicketCustomsDeclarationController {

  @Autowired
  private ICompareTicketCustomsDeclarationService compareTicketCustomsDeclarationServiceImpl;


  /**
   * 查询所有-分页模式
   * @param page 分页对象
   * @param compareTicketCustomsDeclaration 比对报关单
   * @return
   */
  @GetMapping("/compareticketcustomsdeclarations" )
  public XfR getCompareTicketCustomsDeclarations(XfPage page, CompareTicketCustomsDeclaration compareTicketCustomsDeclaration) {
    return XfR.ok(compareTicketCustomsDeclarationServiceImpl.page(page, Wrappers.query(compareTicketCustomsDeclaration)));
  }

  /**
   * 通过id查询比对报关单
   * @param  id
   * @return XfR
   */
  @GetMapping("/compareticketcustomsdeclarations/{id}")
  public XfR getById(@PathVariable Long id) {
     return XfR.ok(compareTicketCustomsDeclarationServiceImpl.getById(id));
  }

  /**
   * 新增比对报关单
   * @param compareTicketCustomsDeclaration 比对报关单
   * @return XfR
   */
  @PostMapping("/compareticketcustomsdeclarations")
  public XfR save(@RequestBody CompareTicketCustomsDeclaration compareTicketCustomsDeclaration) {
     return XfR.ok(compareTicketCustomsDeclarationServiceImpl.save(compareTicketCustomsDeclaration));
  }

  /**
   * 修改-传入修改后的全部数据比对报关单
   * @param compareTicketCustomsDeclaration 比对报关单
   * @return XfR
   */
  @PutMapping("/compareticketcustomsdeclarations/{id}")
  public XfR putUpdate(@RequestBody CompareTicketCustomsDeclaration compareTicketCustomsDeclaration,@PathVariable Long id) {
      compareTicketCustomsDeclaration.setId(id);
      return XfR.ok(compareTicketCustomsDeclarationServiceImpl.updateById(compareTicketCustomsDeclaration));
  }

  /**
   * 修改-传入修改的数据比对报关单
   * @param compareTicketCustomsDeclaration 比对报关单
   * @return XfR
   */
  @PatchMapping("/compareticketcustomsdeclarations/{id}")
  public XfR patchUpdate(@RequestBody CompareTicketCustomsDeclaration compareTicketCustomsDeclaration,@PathVariable Long id) {
      CompareTicketCustomsDeclaration upcompareTicketCustomsDeclaration = compareTicketCustomsDeclarationServiceImpl.getById(id);
      if(upcompareTicketCustomsDeclaration != null){
        upcompareTicketCustomsDeclaration = ObjectCopyUtils.copyProperties(compareTicketCustomsDeclaration,upcompareTicketCustomsDeclaration,true);
      }
      return XfR.ok(compareTicketCustomsDeclarationServiceImpl.updateById(upcompareTicketCustomsDeclaration));
  }

  /**
   * 通过id删除比对报关单
   * @param  id
   * @return XfR
   */
  @DeleteMapping("/compareticketcustomsdeclarations/{id}")
  public XfR removeById(@PathVariable Long id) {
     return XfR.ok(compareTicketCustomsDeclarationServiceImpl.removeById(id));
  }

  @PostMapping("/compareticketcustomsdeclarations/query")
  public XfR querys(@RequestBody ConditionQueryRequest condition) {
     Map<String, Object> params = new HashMap();
     params.put("tableName", "compare_ticket_customs_declaration");
     params.put("request", condition);

     return XfR.ok(compareTicketCustomsDeclarationServiceImpl.querys(params));
  }

}
